@@ -215,162 +215,15 @@ bijiben_init (Bijiben *self)
   priv->is_loaded = FALSE;
 }
 
-/* Import. TODO : move to libbiji */
-
-#define ATTRIBUTES_FOR_NOTEBOOK "standard::content-type,standard::name"
-
-static BijiNoteObj *
-abort_note (BijiNoteObj *rejected)
-{
-  g_object_unref (rejected);
-  return NULL;
-}
-
-static BijiNoteObj *
-copy_note (GFileInfo *info, GFile *container)
-{
-  BijiNoteObj *retval = NULL;
-  const gchar *name;
-  gchar *path;
-  Bijiben *self;
-  BijiNoteBook *book;
-
-  self = BIJIBEN_APPLICATION (g_application_get_default ());
-  book = self->priv->book;
-
-  /* First make sure it's a note */
-  name = g_file_info_get_name (info);
-  if (!g_str_has_suffix (name, ".note"))
-    return NULL;
-
-  /* Deserialize it */
-  path = g_build_filename (g_file_get_path (container), name, NULL);
-  retval = biji_note_get_new_from_file (book, path);
-  g_free (path);
-
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (retval), NULL);
-
-  /* Not a Template */
-  if (biji_note_obj_is_template (retval))
-    return abort_note (retval);
-
-  /* Assign the new path */
-  path = g_build_filename (g_get_user_data_dir (), "bijiben", name, NULL);
-  g_object_set (retval, "path", path, NULL);
-  g_free (path);
-
-  return retval;
-}
-
-static void
-release_enum_cb (GObject *source, GAsyncResult *res, gpointer user_data)
-{
-  g_file_enumerator_close_finish (G_FILE_ENUMERATOR (source), res, NULL);
-  g_object_unref (source);
-}
-
-/* Some notes might have been added previously */
-static void
-go_through_notes_cb (GFileEnumerator *enumerator, GAsyncResult *res, Bijiben *self)
-{
-  GList *notes_info;
-  GList *notes_proposal = NULL;
-  GList *l;
-  GFile *container;
-
-  /* Sanitize title & color */
-  gchar *unique_title, *default_color;
-  BjbSettings *settings;
-  GdkRGBA color;
-
-  container = g_file_enumerator_get_container (enumerator);
-  notes_info = g_file_enumerator_next_files_finish (enumerator, res, NULL);
-  g_file_enumerator_close_async (enumerator, G_PRIORITY_DEFAULT, NULL,
-                                 release_enum_cb, self);
-
-  /* Get the GList of notes and load them */
-  for ( l=notes_info; l !=NULL; l = l->next)
-  {
-    GFileInfo *info = G_FILE_INFO (l->data);
-    BijiNoteObj *iter = copy_note (info, container);
-    if (iter)
-      notes_proposal = g_list_prepend (notes_proposal, iter);
-  }
-
-  for (l = notes_proposal; l != NULL; l = l->next)
-  {
-    BijiNoteObj *note = l->data;
-    const gchar *path = biji_item_get_uuid (BIJI_ITEM (note));
-
-    /* Don't add an already imported note */
-    if (biji_note_book_get_item_at_path (self->priv->book, path))
-    {
-      abort_note (note);
-    }
-
-    /* Sanitize, append & save */
-    else
-    {
-      /* Title */
-      unique_title = biji_note_book_get_unique_title (self->priv->book,
-                                                      biji_item_get_title (BIJI_ITEM (note)));
-      biji_note_obj_set_title (note, unique_title);
-      g_free (unique_title);
-
-      /* Color */
-      settings = bjb_app_get_settings (self);
-      g_object_get (G_OBJECT (settings), "color", &default_color, NULL);
-      if (gdk_rgba_parse (&color, default_color))
-        biji_note_obj_set_rgba (note, &color);
-
-      g_free (default_color);
-
-      biji_note_book_add_item (self->priv->book, BIJI_ITEM (note), FALSE);
-      biji_note_obj_save_note (note);
-    }
-
-  }
-
-  /* NoteBook will notify for all opened windows */
-
-  g_list_free_full (notes_info, g_object_unref);
-  g_list_free (notes_proposal);
-  biji_note_book_notify_changed (self->priv->book, BIJI_BOOK_MASS_CHANGE, NULL);
-}
-
-static void
-list_notes_to_copy (GObject *src_obj, GAsyncResult *res, Bijiben *self)
-{
-  GFileEnumerator *enumerator;
-  GError *error = NULL;
-
-  enumerator = g_file_enumerate_children_finish (G_FILE (src_obj), res, &error);
-
-  if (error)
-  {
-    g_warning ("Enumerator failed : %s", error->message);
-    g_error_free (error);
-    g_file_enumerator_close_async (enumerator, G_PRIORITY_DEFAULT, NULL, release_enum_cb, self);
-  }
-
-  else
-  {
-    g_file_enumerator_next_files_async (enumerator, G_MAXINT, G_PRIORITY_DEFAULT, NULL,
-                                        (GAsyncReadyCallback) go_through_notes_cb, self);
-  }
-}
-
 
 void
 bijiben_import_notes (Bijiben *self, gchar *location)
 {
-  GFile *to_import = g_file_new_for_path (location);
+  g_debug ("IMPORT to %s", bjb_settings_get_default_location (self->priv->settings));
 
-  g_file_enumerate_children_async (to_import, ATTRIBUTES_FOR_NOTEBOOK,
-                                   G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT,
-                                   NULL, (GAsyncReadyCallback) list_notes_to_copy, self);
-
-  g_object_unref (to_import);
+  biji_note_book_import_uri (self->priv->book,
+                             bjb_settings_get_default_location (self->priv->settings),
+                             location);
 }
 
 
