@@ -104,7 +104,8 @@ bjb_controller_init (BjbController *self)
                               G_TYPE_STRING,      // author
                               GDK_TYPE_PIXBUF,    // icon then note
                               G_TYPE_INT64,       // mtime
-                              G_TYPE_BOOLEAN);    // state
+                              G_TYPE_BOOLEAN,     // state
+                              G_TYPE_UINT);       // pulse
 
   priv->model = GTK_TREE_MODEL(store) ;
   priv->items_to_show = NULL;
@@ -294,7 +295,6 @@ bjb_controller_add_item (BjbController *self,
        GD_MAIN_COLUMN_SECONDARY_TEXT, NULL,
        GD_MAIN_COLUMN_ICON, pix,
        GD_MAIN_COLUMN_MTIME, biji_item_get_mtime (item),
-       GD_MAIN_COLUMN_SELECTED, FALSE,
        -1);
 
 }
@@ -347,23 +347,6 @@ bjb_controller_add_item_if_needed (BjbController *self,
     bjb_controller_add_item (self, item, prepend, sibling);
 }
 
-void
-bjb_controller_update_view (BjbController *self)
-{
-  GList *items, *l;
-
-  /* Do not update if nothing to show */
-  if (bjb_window_base_get_view_type (self->priv->window) != BJB_WINDOW_BASE_MAIN_VIEW)
-    return;
-
-  items = self->priv->items_to_show ;
-  free_items_store (self);
-
-  for (l = items; l != NULL; l = l->next)
-  {
-    bjb_controller_add_item (self, l->data, FALSE, NULL);
-  }
-}
 
 static gint
 most_recent_item_first (gconstpointer a, gconstpointer b)
@@ -404,6 +387,27 @@ sort_items (GList **to_show)
 }
 
 
+void
+bjb_controller_update_view (BjbController *self)
+{
+  GList *items, *l;
+
+  /* Do not update if nothing to show */
+  if (bjb_window_base_get_view_type (self->priv->window) != BJB_WINDOW_BASE_MAIN_VIEW)
+    return;
+
+  items = self->priv->items_to_show ;
+  free_items_store (self);
+
+  sort_items (&items);
+
+  for (l = items; l != NULL; l = l->next)
+  {
+    bjb_controller_add_item (self, l->data, FALSE, NULL);
+  }
+}
+
+
 static void
 notify_displayed_items_changed (BjbController *self)
 {
@@ -417,9 +421,14 @@ notify_displayed_items_changed (BjbController *self)
 static void
 update (BjbController *self)
 {
-  bjb_window_base_switch_to (self->priv->window, BJB_WINDOW_BASE_MAIN_VIEW);
-  bjb_controller_update_view (self);
+  /* If the user already edits a note, he does not want the view
+   * to go back */
+  if (bjb_window_base_get_view_type (self->priv->window) !=
+      BJB_WINDOW_BASE_NOTE_VIEW)
+    bjb_window_base_switch_to (self->priv->window, BJB_WINDOW_BASE_MAIN_VIEW);
 
+
+  bjb_controller_update_view (self);
   notify_displayed_items_changed (self);
 }
 
@@ -567,7 +576,7 @@ on_book_changed (BijiNoteBook           *book,
 
           bjb_controller_add_item_if_needed (self, item, TRUE, p_iter);
           priv->n_items_to_show ++;
-          priv->items_to_show = g_list_prepend (priv->items_to_show, note);
+          priv->items_to_show = g_list_prepend (priv->items_to_show, item);
           notify_displayed_items_changed (self);
       break;
 
@@ -611,6 +620,8 @@ on_book_changed (BijiNoteBook           *book,
 
     default:
       bjb_controller_apply_needle (self);
+      if (flag == BIJI_BOOK_MASS_CHANGE)
+        bjb_window_base_set_active (self->priv->window, TRUE);
   }
 
   /* FIXME we refresh the whole completion model each time */
