@@ -70,15 +70,16 @@ GtkTreeModel * bjb_controller_get_model  (BjbController *self) ;
 
 GtkTreeModel * bjb_controller_get_completion(BjbController *self);
 
-void bjb_controller_connect (BjbController *self);
-
 void bjb_controller_disconnect (BjbController *self);
 
 gboolean bjb_controller_shows_item (BjbController *self);
 
-gchar * bjb_controller_get_collection (BjbController *self);
+BijiCollection * bjb_controller_get_collection (BjbController *self);
 
-void bjb_controller_set_collection (BjbController *self, gchar *to_open);
+void bjb_controller_set_collection (BjbController *self, BijiCollection *coll);
+
+
+void bjb_controller_show_more (BjbController *controller);
 
 G_END_DECLS
 
