@@ -44,4 +44,9 @@ biji_error_quark (void)
 }
 
 
-
+GError *
+biji_error_new (BijiErrorType type,
+                gchar *message)
+{
+  return g_error_new (BIJI_ERROR, type, message);
+}
