@@ -15,11 +15,14 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <uuid/uuid.h>
 
 #include "biji-info-set.h"
 #include "biji-item.h"
 #include "biji-own-cloud-note.h"
 #include "biji-own-cloud-provider.h"
+#include "../biji-timeout.h"
+#include "../serializer/biji-lazy-serializer.h"
 
 
 
@@ -28,7 +31,9 @@ struct BijiOwnCloudNotePrivate_
   BijiOwnCloudProvider *prov;
   BijiNoteID *id;
 
-  gchar *html;
+  BijiTimeout           *timeout;
+
+
   GFile *location;
   gchar *basename;
   GCancellable *cancellable; //TODO cancel write to file
@@ -39,20 +44,50 @@ struct BijiOwnCloudNotePrivate_
 G_DEFINE_TYPE (BijiOwnCloudNote, biji_own_cloud_note, BIJI_TYPE_NOTE_OBJ)
 
 
+/* Better not to keep any cache here
+ * We just want cache for overview,
+ * not for actual content
+ *
+ * TODO: this means opening a note has to a be async
+ * which should have been obvious from start */
+
 static gchar *
 ocloud_note_get_html (BijiNoteObj *note)
 {
+  BijiOwnCloudNote *self;
+  gchar *content, *html;
+  GError *err;
+
   g_return_val_if_fail (BIJI_IS_OWN_CLOUD_NOTE (note), NULL);
 
-  return BIJI_OWN_CLOUD_NOTE (note)->priv->html;
+  err = NULL;
+  self = BIJI_OWN_CLOUD_NOTE (note);
+
+  if (g_file_load_contents (self->priv->location, NULL, &content, 0, NULL, &err))
+  {
+    html = html_from_plain_text (content);
+    g_free (content);
+    return html;
+  }
+
+
+  if (err != NULL)
+  {
+    g_warning ("%s", err->message);
+    g_error_free (err);
+  }
+
+
+  return NULL;
 }
 
 
+/* We don't put any html to note. We do not need this */
 static void
 ocloud_note_set_html (BijiNoteObj *note,
                       gchar *html)
 {
-  BIJI_OWN_CLOUD_NOTE (note)->priv->html = g_strdup (html);
+  
 }
 
 
@@ -68,14 +103,16 @@ ocloud_note_ensure_ressource (BijiNoteObj *note)
   BijiOwnCloudNote *ocnote;
   GFile *file;
   GFileInfo *file_info;
-  const BijiProviderInfo *prov_info;
+  const BijiProviderInfo *provider;
 
   g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (note));
+  g_return_if_fail (G_IS_FILE (BIJI_OWN_CLOUD_NOTE (note)->priv->location));
+
   item = BIJI_ITEM (note);
   ocnote = BIJI_OWN_CLOUD_NOTE (note);
   file = ocnote->priv->location;
   file_info = g_file_query_info (file, "time::modified", G_FILE_QUERY_INFO_NONE, NULL, NULL);
-  prov_info = biji_provider_get_info (BIJI_PROVIDER (ocnote->priv->prov));
+  provider = biji_provider_get_info (BIJI_PROVIDER (ocnote->priv->prov));
 
   info = biji_info_set_new ();
   info->url = (gchar*) biji_item_get_uuid (item);
@@ -83,7 +120,7 @@ ocloud_note_ensure_ressource (BijiNoteObj *note)
   info->content = (gchar*) biji_note_obj_get_raw_text (note);
   info->mtime = g_file_info_get_attribute_uint64 (file_info, "time::modified");
   info->created = biji_note_obj_get_create_date (note);
-  info->datasource_urn = g_strdup (prov_info->datasource);
+  info->datasource_urn = g_strdup (provider->datasource);
 
   biji_tracker_ensure_ressource_from_info  (biji_item_get_book (item),
                                             info);
@@ -114,12 +151,15 @@ on_content_replaced  (GObject *source_object,
 
   else
   {
+    biji_note_obj_save_icon (user_data);
     ocloud_note_ensure_ressource (user_data);
   }
 }
 
 
 
+
+
 static void
 ocloud_note_save (BijiNoteObj *note)
 {
@@ -130,6 +170,7 @@ ocloud_note_save (BijiNoteObj *note)
   self = BIJI_OWN_CLOUD_NOTE (note);
   str = g_string_new (biji_note_obj_get_raw_text (note));
 
+
   /* backup would fail for some reason. 
    * gfilemove for workaround? */
   g_file_replace_contents_async  (
@@ -148,86 +189,73 @@ ocloud_note_save (BijiNoteObj *note)
 }
 
 
+
+
+
+
+
+
 /* Rename the file
  * when note title change
- * Also handle new notes being populated */
+ * Also handle new notes being populated
+ * the noteID still keep some path, which we will remove */
 
 static void
 create_new_file (BijiOwnCloudNote *self, const gchar *basename)
 {
   GFile *folder;
   BijiNoteObj *note;
+  gchar *key;
 
   note = BIJI_NOTE_OBJ (self);
   folder = biji_own_cloud_provider_get_folder (self->priv->prov);
 
+  /* TODO just free old location before, but check for no mistake */
+
   self->priv->location = g_file_get_child (folder, basename);
-  self->priv->basename = g_file_get_basename (self->priv->location);
+  key = g_strdup_printf (
+               "%s/%s",
+               biji_own_cloud_provider_get_readable_path (self->priv->prov),
+               basename);
+  g_object_set (self->priv->id, "path", key, NULL);
 
   ocloud_note_save (note);
   ocloud_note_ensure_ressource (note);
+
+  g_free (key);
 }
 
 
-/* with current design, title might change
- * from user will or because note is edited */
+/* When the title is stable, handle io */
+static void
+on_timeout (BijiOwnCloudNote *self)
+{
+  create_new_file (self, self->priv->basename);
+}
+
 
 static void
-on_title_change                     (gpointer    user_data)
+on_title_change                     (BijiOwnCloudNote *self)
 {
-  BijiOwnCloudNote *self;
-  gchar *old_title;
   const gchar *new_title;
 
+  g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (self));
 
-  g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (user_data));
-
-  self = BIJI_OWN_CLOUD_NOTE (user_data);
-  old_title = self->priv->basename;
+  g_free (self->priv->basename);
   new_title = biji_note_id_get_title (self->priv->id);
+  self->priv->basename = g_strdup_printf ("%s.txt", new_title);
 
-  
-  if (old_title == NULL)
-  {
-    if (new_title != NULL)
-      create_new_file (self, new_title);
-  }
 
-  else if (g_strcmp0 (old_title, new_title) != 0)
-  {
-    g_file_delete_async (self->priv->location,
-                         G_PRIORITY_LOW,
-                         NULL,
-                         NULL,
-                         NULL);
-    // g_object_unref (self->priv->location);
-    // g_free (self->priv->basename);
-    create_new_file (self, new_title);
-  }
-  
+  g_file_delete_async (self->priv->location,
+                       G_PRIORITY_LOW,
+                       NULL,
+                       NULL,
+                       NULL);
+
+  biji_timeout_reset (self->priv->timeout, 3000);
 }
 
 
-/* TODO : check if the title needs change
- * and adjust */
-
-static void
-on_content_change                   (gpointer    user_data)
-{
-  BijiNoteObj *note;
-  gchar *html;
-
-  g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (user_data));
-
-  note = user_data;
-  html = html_from_plain_text ((gchar*) biji_note_obj_get_raw_text (user_data));
-  ocloud_note_set_html (note, html);
-  g_free (html);
-}
-
-
-
-
 
 
 static void
@@ -238,8 +266,9 @@ biji_own_cloud_note_finalize (GObject *object)
   g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (object));
 
   self = BIJI_OWN_CLOUD_NOTE (object);
-  g_free (self->priv->html);
+
   g_object_unref (self->priv->cancellable);
+  g_object_unref (self->priv->timeout);
   G_OBJECT_CLASS (biji_own_cloud_note_parent_class)->finalize (object);
 }
 
@@ -250,8 +279,6 @@ biji_own_cloud_note_constructed (GObject *object)
   g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (object));
 
   G_OBJECT_CLASS (biji_own_cloud_note_parent_class)->constructed (object);
-  
-  on_content_change ((gpointer) object);
 }
 
 
@@ -261,6 +288,10 @@ biji_own_cloud_note_init (BijiOwnCloudNote *self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BIJI_TYPE_OWN_CLOUD_NOTE, BijiOwnCloudNotePrivate);
   self->priv->cancellable = g_cancellable_new ();
   self->priv->id = NULL;
+
+  self->priv->timeout = biji_timeout_new ();
+  g_signal_connect_swapped (self->priv->timeout, "timeout",
+                            G_CALLBACK (on_timeout), self);
 }
 
 
@@ -327,9 +358,34 @@ BijiNoteObj        *biji_own_cloud_note_new_from_info           (BijiOwnCloudPro
                                                                  BijiInfoSet *info)
 {
   BijiNoteID *id;
+  gchar *sane_title;
   BijiNoteObj *retval;
   BijiOwnCloudNote *ocloud;
 
+  /* First, sanitize the title, assuming no other thread
+   * mess up with the InfoSet */
+  sane_title = biji_str_replace (info->title, ".txt", "");
+  g_free (info->title);
+  info->title = sane_title;
+
+
+  /* Hmm, even if the note starts blank we want some path...*/
+
+  if (info->url == NULL)
+  {
+    uuid_t unique;
+    char out[40];
+
+    uuid_generate (unique);
+    uuid_unparse_lower (unique, out);
+    
+    info->url = g_strdup_printf ("%s/%s.txt",
+                  biji_own_cloud_provider_get_readable_path (prov),
+                  out);
+  }
+
+  /* Now actually create the stuff */
+
   id = biji_note_id_new_from_info (info);
 
   retval = g_object_new (BIJI_TYPE_OWN_CLOUD_NOTE,
@@ -341,26 +397,12 @@ BijiNoteObj        *biji_own_cloud_note_new_from_info           (BijiOwnCloudPro
   ocloud->priv->id = id;
   ocloud->priv->prov = prov;
   biji_note_obj_set_create_date (retval, info->created);
-  g_signal_connect_swapped (id, "notify::content",
-                            G_CALLBACK (on_content_change), retval);
   g_signal_connect_swapped (id, "notify::title",
                             G_CALLBACK (on_title_change), retval);
 
-  /* That's not a blank note. That's an existing file. */
 
-  if (info->url != NULL)
-  {
-    ocloud->priv->location = g_file_new_for_commandline_arg (info->url);
-    ocloud->priv->basename = g_file_get_basename (ocloud->priv->location);
-  }
-
-  /* Really new note */
-
-  else
-  {
-    ocloud->priv->location = NULL;
-    ocloud->priv->basename = NULL;
-  }
+  ocloud->priv->location = g_file_new_for_commandline_arg (info->url);
+  ocloud->priv->basename = g_file_get_basename (ocloud->priv->location);
 
   return retval;
 }
